@@ -41,7 +41,7 @@ void PlasmoidPackageTest::initTestCase()
 void PlasmoidPackageTest::init()
 {
     qDebug() << "PlasmoidPackage::init()";
-    m_package = QString("Package");
+    m_package = QStringLiteral("Package");
     m_packageRoot = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + "/packageRoot";
     m_defaultPackage = KPackage::Package(new KPackage::PlasmoidPackage);
     cleanup(); // to prevent previous runs from interfering with this one
@@ -186,7 +186,12 @@ void PlasmoidPackageTest::isValid()
     p = new KPackage::Package(m_defaultPackage);
     p->setPath(m_packageRoot + '/' + m_package);
     QVERIFY(p->isValid());
-    QCOMPARE(p->contentsHash(), QString("a41160c6a763ea505c95bee12a7fc87952a61cf1"));
+    // Ignore deprecation warning, we are actually testing this here.
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+    QCOMPARE(p->contentsHash(), QStringLiteral("a41160c6a763ea505c95bee12a7fc87952a61cf1"));
+#pragma GCC diagnostic pop
+    QCOMPARE(p->cryptographicHash(QCryptographicHash::Sha1), QByteArrayLiteral("a41160c6a763ea505c95bee12a7fc87952a61cf1"));
     delete p;
 }
 
@@ -199,7 +204,7 @@ void PlasmoidPackageTest::filePath()
     KPackage::Package *p = new KPackage::Package(m_defaultPackage);
     p->setPath(m_packageRoot + '/' + m_package);
 
-    QCOMPARE(p->filePath("scripts", "main"), QString());
+    QCOMPARE(p->filePath("scripts", QStringLiteral("main")), QString());
 
     QVERIFY(QDir().mkpath(m_packageRoot + "/" + m_package + "/contents/ui/main.qml"));
     QFile file(m_packageRoot + "/" + m_package + "/contents/ui/main.qml");
@@ -224,7 +229,7 @@ void PlasmoidPackageTest::filePath()
     //
     // NOTE: scripts, main and mainscript are defined in packages.cpp and are
     //       specific for a PlasmoidPackage.
-    QCOMPARE(p->filePath("scripts", "main"), path);
+    QCOMPARE(p->filePath("scripts", QStringLiteral("main")), path);
     QCOMPARE(p->filePath("mainscript"), path);
     delete p;
 }
@@ -232,7 +237,7 @@ void PlasmoidPackageTest::filePath()
 void PlasmoidPackageTest::entryList()
 {
     // Create a package named @p packageName which is valid and has some images.
-    createTestPackage(m_package, QLatin1String("1.1"));
+    createTestPackage(m_package, QStringLiteral("1.1"));
 
     // Create a package object and verify that it is valid.
     KPackage::Package *p = new KPackage::Package(m_defaultPackage);
@@ -246,12 +251,12 @@ void PlasmoidPackageTest::entryList()
     // images - {"image-1.svg", "image-2.svg"}
     QStringList files = p->entryList("scripts");
     QCOMPARE(files.size(), 1);
-    QVERIFY(files.contains("script.js"));
+    QVERIFY(files.contains(QStringLiteral("script.js")));
 
     files = p->entryList("images");
     QCOMPARE(files.size(), 2);
-    QVERIFY(files.contains("image-1.svg"));
-    QVERIFY(files.contains("image-2.svg"));
+    QVERIFY(files.contains(QStringLiteral("image-1.svg")));
+    QVERIFY(files.contains(QStringLiteral("image-2.svg")));
     delete p;
 }
 
@@ -259,12 +264,12 @@ void PlasmoidPackageTest::createAndInstallPackage()
 {
     qDebug() << "                   ";
     qDebug() << "   CreateAndInstall ";
-    createTestPackage("plasmoid_to_package", QLatin1String("1.1"));
+    createTestPackage(QStringLiteral("plasmoid_to_package"), QStringLiteral("1.1"));
     const QString packagePath = m_packageRoot + '/' + "testpackage.plasmoid";
 
     KZip creator(packagePath);
     QVERIFY(creator.open(QIODevice::WriteOnly));
-    creator.addLocalDirectory(m_packageRoot + '/' + "plasmoid_to_package", ".");
+    creator.addLocalDirectory(m_packageRoot + '/' + "plasmoid_to_package", QStringLiteral("."));
     creator.close();
     QDir rootDir(m_packageRoot + "/plasmoid_to_package");
     rootDir.removeRecursively();
@@ -275,13 +280,13 @@ void PlasmoidPackageTest::createAndInstallPackage()
     QVERIFY(package.open(QIODevice::ReadOnly));
     const KArchiveDirectory *dir = package.directory();
     QVERIFY(dir);//
-    QVERIFY(dir->entry("metadata.desktop"));
-    const KArchiveEntry *contentsEntry = dir->entry("contents");
+    QVERIFY(dir->entry(QStringLiteral("metadata.desktop")));
+    const KArchiveEntry *contentsEntry = dir->entry(QStringLiteral("contents"));
     QVERIFY(contentsEntry);
     QVERIFY(contentsEntry->isDirectory());
     const KArchiveDirectory *contents = static_cast<const KArchiveDirectory *>(contentsEntry);
-    QVERIFY(contents->entry("ui"));
-    QVERIFY(contents->entry("images"));
+    QVERIFY(contents->entry(QStringLiteral("ui")));
+    QVERIFY(contents->entry(QStringLiteral("images")));
 
     m_defaultPackageStructure = new KPackage::PackageStructure(this);
     KPackage::Package *p = new KPackage::Package(m_defaultPackageStructure);
@@ -292,7 +297,10 @@ void PlasmoidPackageTest::createAndInstallPackage()
     connect(job, SIGNAL(finished(KJob*)), SLOT(packageInstalled(KJob*)));
     QSignalSpy spy(job, SIGNAL(finished(KJob*)));
     QVERIFY(spy.wait(1000));
-    cleanupPackage("plasmoid_to_package");
+
+    //is the package instance usable (ie proper path) after the install job has been completed?
+    QCOMPARE(p->path(), QString(m_packageRoot % "/plasmoid_to_package/"));
+    cleanupPackage(QStringLiteral("plasmoid_to_package"));
 
     //QVERIFY(p->isValid());
     delete p;
@@ -301,21 +309,21 @@ void PlasmoidPackageTest::createAndInstallPackage()
 void PlasmoidPackageTest::createAndUpdatePackage()
 {
     //does the version number parsing work?
-    QVERIFY(KPackage::isVersionNewer("1.1", "1.1.1"));
-    QVERIFY(!KPackage::isVersionNewer("1.1.1", "1.1"));
-    QVERIFY(KPackage::isVersionNewer("1.1.1", "1.1.2"));
-    QVERIFY(KPackage::isVersionNewer("1.1.2", "2.1"));
-    QVERIFY(KPackage::isVersionNewer("0.1.2", "2"));
-    QVERIFY(!KPackage::isVersionNewer("1", "0.1.2"));
+    QVERIFY(KPackage::isVersionNewer(QStringLiteral("1.1"), QStringLiteral("1.1.1")));
+    QVERIFY(!KPackage::isVersionNewer(QStringLiteral("1.1.1"), QStringLiteral("1.1")));
+    QVERIFY(KPackage::isVersionNewer(QStringLiteral("1.1.1"), QStringLiteral("1.1.2")));
+    QVERIFY(KPackage::isVersionNewer(QStringLiteral("1.1.2"), QStringLiteral("2.1")));
+    QVERIFY(KPackage::isVersionNewer(QStringLiteral("0.1.2"), QStringLiteral("2")));
+    QVERIFY(!KPackage::isVersionNewer(QStringLiteral("1"), QStringLiteral("0.1.2")));
 
     qDebug() << "                   ";
     qDebug() << "   CreateAndUpdate ";
-    createTestPackage("plasmoid_to_package", QLatin1String("1.1"));
+    createTestPackage(QStringLiteral("plasmoid_to_package"), QStringLiteral("1.1"));
     const QString packagePath = m_packageRoot + '/' + "testpackage.plasmoid";
 
     KZip creator(packagePath);
     QVERIFY(creator.open(QIODevice::WriteOnly));
-    creator.addLocalDirectory(m_packageRoot + '/' + "plasmoid_to_package", ".");
+    creator.addLocalDirectory(m_packageRoot + '/' + "plasmoid_to_package", QStringLiteral("."));
     creator.close();
     QDir rootDir(m_packageRoot + "/plasmoid_to_package");
     rootDir.removeRecursively();
@@ -326,13 +334,13 @@ void PlasmoidPackageTest::createAndUpdatePackage()
     QVERIFY(package.open(QIODevice::ReadOnly));
     const KArchiveDirectory *dir = package.directory();
     QVERIFY(dir);//
-    QVERIFY(dir->entry("metadata.desktop"));
-    const KArchiveEntry *contentsEntry = dir->entry("contents");
+    QVERIFY(dir->entry(QStringLiteral("metadata.desktop")));
+    const KArchiveEntry *contentsEntry = dir->entry(QStringLiteral("contents"));
     QVERIFY(contentsEntry);
     QVERIFY(contentsEntry->isDirectory());
     const KArchiveDirectory *contents = static_cast<const KArchiveDirectory *>(contentsEntry);
-    QVERIFY(contents->entry("ui"));
-    QVERIFY(contents->entry("images"));
+    QVERIFY(contents->entry(QStringLiteral("ui")));
+    QVERIFY(contents->entry(QStringLiteral("images")));
 
     m_defaultPackageStructure = new KPackage::PackageStructure(this);
     KPackage::Package *p = new KPackage::Package(m_defaultPackageStructure);
@@ -354,11 +362,11 @@ void PlasmoidPackageTest::createAndUpdatePackage()
 
 
     //create a new package with higher version
-    createTestPackage("plasmoid_to_package", QLatin1String("1.2"));
+    createTestPackage(QStringLiteral("plasmoid_to_package"), QStringLiteral("1.2"));
 
     KZip creator2(packagePath);
     QVERIFY(creator2.open(QIODevice::WriteOnly));
-    creator2.addLocalDirectory(m_packageRoot + '/' + "plasmoid_to_package", ".");
+    creator2.addLocalDirectory(m_packageRoot + '/' + "plasmoid_to_package", QStringLiteral("."));
     creator2.close();
     QDir rootDir2(m_packageRoot + "/plasmoid_to_package");
     rootDir2.removeRecursively();
@@ -369,7 +377,7 @@ void PlasmoidPackageTest::createAndUpdatePackage()
     QSignalSpy spy2(job2, SIGNAL(finished(KJob*)));
     QVERIFY(spy2.wait(1000));
 
-    cleanupPackage("plasmoid_to_package");
+    cleanupPackage(QStringLiteral("plasmoid_to_package"));
 
     //QVERIFY(p->isValid());
     delete p;
@@ -379,7 +387,10 @@ void PlasmoidPackageTest::cleanupPackage(const QString &packageName)
 {
     KPackage::Package *p = new KPackage::Package(m_defaultPackageStructure);
     KJob *jj = p->uninstall(packageName, m_packageRoot);
-    connect(jj, SIGNAL(finished(KJob*)), SLOT(packageInstalled(KJob*)));
+    connect(jj, SIGNAL(finished(KJob*)), SLOT(packageUninstalled(KJob*)));
+
+    QSignalSpy spy(jj, &KJob::finished);
+    QVERIFY(spy.wait(1000));
 }
 
 void PlasmoidPackageTest::packageInstalled(KJob *j)
